# estate forget

    estate forget [<pathspec>...]

The `estate forget` command is essentially an alias for `git rm --cached`.
With it, you can remove files from version control without removing them
from the work tree.
